import json
from os.path import isfile
from pathlib import Path

from PySide6.QtGui import QColor
from PySide6.QtWidgets import QWidget, QVBoxLayout, QLineEdit, QPushButton

from src.plugins._plugin import Plugin, get_int_from_qcolor

path = f'{Path.home()}/.config/BraveSoftware/Brave-Browser/Default/Preferences'


class Brave(Plugin):
    def __init__(self):
        super().__init__()
        self.theme_light = '#ffffff'
        self.theme_dark = '#000000'

    def set_theme(self, color_str: str):
        with open(path, 'r') as file:
            config = json.load(file)

        color = get_int_from_qcolor(QColor(color_str))
        config['autogenerated']['theme']['color'] = color

    def get_input(self, widget):
        widgets = []

        for dark_theme in [False, True]:
            grp = QWidget(widget)
            horizontal_layout = QVBoxLayout(grp)

            line = QLineEdit(grp)
            color_str = self.theme_dark if dark_theme else self.theme_light
            line.setText(color_str)
            color = QColor(color_str)
            line.setStyleSheet(f'background-color: {color_str};'
                               f' color: {"white" if color.lightness() <= 128 else "black"}')
            horizontal_layout.addWidget(line)

            btn = QPushButton()
            btn.setText(f'Pick {"dark" if dark_theme else "light"} color')
            horizontal_layout.addWidget(btn)

            widgets.append(grp)

        return widgets

    @property
    def available(self) -> bool:
        return isfile(path)
